==> commerce_cashfree_payment-1.0.2.tar.gz: commerce_cashfree_payment/src/PluginForm/CashfreeRedirect/PaymentCashfreeForm.php <==
<?php

namespace Drupal\commerce_cashfree_payment\PluginForm\CashfreeRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\commerce_order\Entity\Order;

/**
 * Implements PaymentCashfree Form class.
 *
 * - this class used for build to payment form.
 */
class PaymentCashfreeForm extends PaymentOffsiteForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    $order_id = \Drupal::routeMatch()->getParameter('commerce_order')->id();
    $order = Order::load($order_id);
    $mode = $payment_gateway_plugin->getConfiguration()['pmode'];
    $appId = $payment_gateway_plugin->getConfiguration()['app_id'];
    $secretkey = $payment_gateway_plugin->getConfiguration()['secretkey'];
    $cur = $payment_gateway_plugin->getConfiguration()['currency'];
    $address = $order->getBillingProfile()->address->first();
    $amount = number_format($payment->getAmount()->getNumber() * 100, 0, '.', '');
    $name = $address->getGivenName();
    $order_email = $order->getEmail();
    $phone = $order->getBillingProfile()->get('field_phone_number')->value;
    $redirect = Url::fromUri('base:/checkout/' . $order_id . '/payment/return/', ['absolute' => TRUE])
      ->toString();
    $postData = [
      'appId' => $appId,
      'orderId' => $order_id,
      'orderAmount' => $amount,
      'orderCurrency' => $cur,
      'customerName' => $name,
      'customerPhone' => $phone,
      'customerEmail' => $order_email,
      'returnUrl' => $redirect,
    ];
    ksort($postData);
    $signatureData = "";
    foreach ($postData as $key => $value) {
      $signatureData .= $key . $value;
    }
    $signature = hash_hmac('sha256', $signatureData, $secretkey, TRUE);
    $signature = base64_encode($signature);
    $postData["signature"] = $signature;

    if ($mode == "PROD") {
      $url = "https://www.cashfree.com/checkout/post/submit";
    }
    else {
      $url = "https://test.cashfree.com/billpay/checkout/post/submit";
    }
    return $this->buildRedirectForm($form, $form_state, $url, $postData, PaymentOffsiteForm::REDIRECT_POST);
  }

}

==> commerce_cashfree_payment-8.0.0.tar.gz: commerce_cashfree_payment/src/PluginForm/CashfreeRedirect/PaymentCashfreeForm.php <==
<?php

namespace Drupal\commerce_cashfree_payment\PluginForm\CashfreeRedirect;

use Drupal\commerce_payment\PluginForm\PaymentOffsiteForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\commerce_order\Entity\Order;
use Drupal\user\Entity\User;
/**
 * Implements PaymentCashfree Form class.
 *
 * - this class used for build to payment form.
 */
class PaymentCashfreeForm extends PaymentOffsiteForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    $redirect_method = 'post';
    $parameters = [];
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\OffsitePaymentGatewayInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $payment->getPaymentGateway()->getPlugin();
    $order_id = \Drupal::routeMatch()->getParameter('commerce_order')->id();
    $order = Order::load($order_id);
    $mode = $payment_gateway_plugin->getConfiguration()['pmode'];
    $appId = $payment_gateway_plugin->getConfiguration()['app_id'];
    $secretkey = $payment_gateway_plugin->getConfiguration()['secretkey'];
    $cur = $payment_gateway_plugin->getConfiguration()['currency'];
    $userCurrent = \Drupal::currentUser();
    $user = User::load($userCurrent->id());
    $amount = number_format($payment->getAmount()->getNumber()*100, 0, '.', '');
    $name = $user->getUsername();
    $order_email = $order->getEmail();
    $phone = $order->getBillingProfile()->get('field_phone_number')->value;
    $product_id = $payment_gateway_plugin->getConfiguration()['product_id'];
    $redirect = Url::fromUri('base:/checkout/' . $order_id . '/payment/return/', ['absolute' => TRUE])
      ->toString();
    $postData = [
      'appId' => $appId, 
      'orderId' => $order_id, 
      'orderAmount' => $amount, 
      'orderCurrency' => $cur, 
      'customerName' => $name, 
      'customerPhone' => $phone, 
      'customerEmail' => $order_email,
      'returnUrl' => $redirect, 
    ];
    ksort($postData);
    $signatureData = "";
    foreach ($postData as $key => $value){
      $signatureData .= $key.$value;
    }
    $signature = hash_hmac('sha256', $signatureData, $secretkey,true);
    $signature = base64_encode($signature);
    $postData["signature"] = $signature;

    if ($mode == "PROD") {
      $url = "https://www.cashfree.com/checkout/post/submit";
    } else {
      $url = "https://test.cashfree.com/billpay/checkout/post/submit";
    }
  return $this->buildRedirectForm($form,$form_state,$url,$postData,PaymentOffsiteForm::REDIRECT_POST);
  }
}
